@@ -12,7 +12,6 @@ from PIL.Image import Image as IMG
 from PIL.ImageFont import FreeTypeFont
 from PIL import Image, ImageDraw, ImageFilter, ImageFont
 from emoji.unicode_codes import UNICODE_EMOJI
-from nonebot.log import logger
 
 from .download import get_font, get_image
 from .models import Command
@@ -57,11 +56,20 @@ async def draw_text(
 ):
     if not text:
         return
-    lines = text.strip().split("\n")
-    logger.info(lines)
+
     draw = ImageDraw.Draw(img)
-    max_w = font.getsize_multiline(text, spacing=spacing, stroke_width=stroke_width)[0]
-    current_x, current_y = pos
+    if all([char not in UNICODE_EMOJI["en"] for char in text]):
+        draw.multiline_text(
+            pos,
+            text,
+            font=font,
+            fill=fill,
+            spacing=spacing,
+            align=align,
+            stroke_width=stroke_width,
+            stroke_fill=stroke_fill,
+        )
+        return
 
     emoji_font_file = BytesIO(await get_font(EMOJI_FONT))
     emoji_font = ImageFont.truetype(emoji_font_file, 109, encoding="utf-8")
@@ -73,8 +81,27 @@ async def draw_text(
                 return True
         return False
 
+    lines = text.strip().split("\n")
+    max_w = font.getsize_multiline(text)[0]
+    current_x, current_y = pos
+    current_text = ""
+
+    def draw_current_text():
+        nonlocal current_x, current_text
+        if current_text:
+            draw.text(
+                (current_x, current_y),
+                current_text,
+                font=font,
+                fill=fill,
+                stroke_width=stroke_width,
+                stroke_fill=stroke_fill,
+            )
+            current_x += font.getsize(current_text)[0]
+            current_text = ""
+
     for line in lines:
-        line_w = font.getsize(line, stroke_width=stroke_width)[0]
+        line_w = font.getsize(line)[0]
         dw = max_w - line_w
         current_x = pos[0]
         if align == "center":
@@ -84,26 +111,20 @@ async def draw_text(
 
         for char in line:
             if char in UNICODE_EMOJI["en"] and has_emoji(char):
+                draw_current_text()
                 emoji_img = Image.new("RGBA", (150, 150))
                 emoji_draw = ImageDraw.Draw(emoji_img)
                 emoji_draw.text((0, 0), char, font=emoji_font, embedded_color=True)
                 emoji_img = emoji_img.crop(emoji_font.getbbox(char))
-                emoji_x, emoji_y = font.getsize(char, stroke_width=stroke_width)
+                emoji_x, emoji_y = font.getsize(char)
                 emoji_img = fit_size(
                     emoji_img, (emoji_x, emoji_y), FitSizeMode.INSIDE, FitSizeDir.SOUTH
                 )
                 img.paste(emoji_img, (int(current_x), int(current_y)), emoji_img)
                 current_x += emoji_x
             else:
-                draw.text(
-                    (current_x, current_y),
-                    char,
-                    font=font,
-                    fill=fill,
-                    stroke_width=stroke_width,
-                    stroke_fill=stroke_fill,
-                )
-                current_x += font.getsize(char, stroke_width=stroke_width)[0]
+                current_text += char
+        draw_current_text()
         current_y += font.getsize("A", stroke_width=stroke_width)[1] + spacing
 
 
